@@ -4,7 +4,7 @@ import subprocess as sp
 
 def main():
  sp.call("wget https://github.com/ytakefuji/covid_score_japan/raw/main/jppop.xlsx --no-check-certificate",shell=True)
- df = pd.read_excel('jppop.xlsx')
+ df = pd.read_excel('jppop.xlsx',engine='openpyxl')
  df=df[1:48]
  df=df.rename({ 'Unnamed: 1':'jPref'},axis=1)
  df.to_csv('pop.csv')
